<?php
namespace Ak\Db\Adapter;

use Ak\Db\Adapter\Driver\DriverAbstractFactory;
use Interop\Container\ContainerInterface;
use Laminas\Db\Adapter\Adapter;
use Laminas\Db\Adapter\AdapterInterface;
use Laminas\ServiceManager\Factory\AbstractFactoryInterface;

/**
 * Stvara nove instance DB adaptera.
 *
 * @package Ak\Db\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/db
 */
class AdapterAbstractFactory implements AbstractFactoryInterface
{
    /**
     * Dali uopće znamo napraviti ovaj db adapter?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     *
     * @return bool
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        $config = $container->get('config')['db'] ?? [];

        if ('db' === $requestedName || AdapterInterface::class === $requestedName) {
            return array_key_exists('driver', $config);
        }

        return isset($config['adapters'][$requestedName]) && is_array($config['adapters'][$requestedName]);
    }

    /**
     * Stvara instancu.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AdapterInterface
     * @throws \Doctrine\DBAL\DBALException
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $configFactory = new AdapterConfigFactory();
        $config = $configFactory($container, $requestedName);

        $driverFactory = new DriverAbstractFactory();
        $driver = $driverFactory($container, $config['driver'], $config);

        $platformName = preg_replace('/driver/', 'platform', $config['driver']);
        $platform = $container->get($platformName);

        if (method_exists($platform, 'setDriver')) {
            $connection = $driver->getConnection();
            $connection->connect();

            $platform->setDriver($connection->getResource());
        }

        return new Adapter($driver, $platform);
    }
}
