<?php
namespace Ak\Db\Adapter\Driver\Dbal;

use Doctrine\DBAL\Connection as BaseConnection;
use Doctrine\DBAL\Driver\PDOConnection;
use Laminas\Db\Adapter\Driver\ConnectionInterface;
use Laminas\Db\Adapter\Driver\Pdo\Result;
use Laminas\Db\Adapter\Driver\ResultInterface;

/**
 * Klasa za konekciju.
 *
 * @package Ak\Db\Adapter\Driver\Dbal
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/db
 */
class Connection extends BaseConnection implements ConnectionInterface
{
    /**
     * Get current schema
     *
     * @return string
     */
    public function getCurrentSchema()
    {
        return $this->getDatabase();
    }

    /**
     * Get resource
     *
     * @return PDOConnection
     */
    public function getResource()
    {
        return $this->_conn;
    }

    /**
     * Disconnect
     *
     * @return ConnectionInterface
     */
    public function disconnect()
    {
        $this->close();
        return $this;
    }

    /**
     * Execute
     *
     * @param  string $sql
     * @return ResultInterface
     * @throws \Doctrine\DBAL\DBALException
     */
    public function execute($sql)
    {
        $statement = $this->query($sql);

        $result = new Result();
        /** @noinspection PhpParamsInspection */
        $result->initialize($statement, $this->lastInsertId(), $statement->rowCount());

        return $result;
    }

    /**
     * Get last generated id
     *
     * @param  null $name Ignored
     * @return int
     */
    public function getLastGeneratedValue($name = null)
    {
        return $this->lastInsertId();
    }
}
