<?php
namespace AkTest\Db\Adapter\Driver;

use Ak\Db\Adapter\Driver\Dbal;
use Ak\Db\Adapter\Driver\DriverAbstractFactory;
use Ak\Test\AbstractTestCase;

/**
 * Class DriverAbstractFactoryTest
 *
 * @package AkTest\Db\Adapter\Driver
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/db
 */
class DriverAbstractFactoryTest extends AbstractTestCase
{
    public function testKnowsHowToCreateDrivers()
    {
        $container = $this->getContainer();
        $factory = new DriverAbstractFactory();

        $this->assertTrue($factory->canCreate($container, 'db.driver.mysql'));
        $this->assertTrue($factory->canCreate($container, 'db.driver.sqlsrv'));
        $this->assertTrue($factory->canCreate($container, 'db.driver.sqlite'));
    }

    public function testDoesnKnowHowToCreateUnknownDrivers()
    {
        $container = $this->getContainer();
        $factory = new DriverAbstractFactory();

        $this->assertFalse($factory->canCreate($container, 'invalid'));
    }

    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testCanCreateMysqlDriver()
    {
        $container = $this->getContainer();
        $factory = new DriverAbstractFactory();

        $mysql = $factory($container, 'db.driver.mysql');

        $this->assertInstanceOf(Dbal\DbalMysql::class, $mysql);
        $this->assertInstanceOf(Dbal\Connection::class, $mysql->getConnection());
    }

    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testCanCreateSqliteDriver()
    {
        $container = $this->getContainer();
        $factory = new DriverAbstractFactory();

        $sqlite = $factory($container, 'db.driver.sqlite');

        $this->assertInstanceOf(Dbal\DbalSqlite::class, $sqlite);
        $this->assertInstanceOf(Dbal\Connection::class, $sqlite->getConnection());
    }

    /**
     * @expectedException \InvalidArgumentException
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testWillThrowExceptionForInvalidDriver()
    {
        $container = $this->getContainer();
        $factory = new DriverAbstractFactory();

        $factory($container, 'invalid');
    }
}
