<?php
namespace AkTest\Db\Adapter\Platform;

use Ak\Db\Adapter\Platform\PlatformAbstractFactory;
use Ak\Test\AbstractTestCase;
use Laminas\Db\Adapter\Platform\PlatformInterface;

/**
 * Class PlatformAbstractFactoryTest
 *
 * @package AkTest\Db\Adapter\Platform
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/db
 */
class PlatformAbstractFactoryTest extends AbstractTestCase
{
    public function testKnowsHowToCreatePlatforms()
    {
        $container = $this->getContainer();
        $factory = new PlatformAbstractFactory();

        $this->assertTrue($factory->canCreate($container, 'db.platform.Mysql'));
        $this->assertTrue($factory->canCreate($container, 'db.platform.SqlSrv'));
        $this->assertTrue($factory->canCreate($container, 'db.platform.Sqlite'));
    }

    public function testDoesntKnowHowToCreateUnknownPlatforms()
    {
        $container = $this->getContainer();
        $factory = new PlatformAbstractFactory();

        $this->assertFalse($factory->canCreate($container, 'invalid'));
    }

    public function testCanCreatePlatforms()
    {
        $container = $this->getContainer();
        $factory = new PlatformAbstractFactory();

        $this->assertInstanceOf(PlatformInterface::class, $factory($container, 'db.platform.mysql'));
        $this->assertInstanceOf(PlatformInterface::class, $factory($container, 'db.platform.sqlite'));
    }

    /**
     * @expectedException \Laminas\ServiceManager\Exception\ServiceNotCreatedException
     */
    public function testWillThrowExceptionForInvalidPlatform()
    {
        $container = $this->getContainer();
        $factory = new PlatformAbstractFactory();

        $factory($container, 'invalid');
    }
}
